@@ -1,17 +1,17 @@
-#!perl
 package DateTimeX::Mashup::Shiras::Types;
+use version 0.94; our $VERSION = qv("v0.22.2");
 
-use version 0.94; our $VERSION = qv('0.020.002');
+use 5.010;
 use DateTime;
 use DateTime::Format::Epoch 0.013;
 use DateTime::Format::Excel;
-use DateTime::Format::DateManip;
+use DateTime::Format::Flexible;
 use MooseX::Types -declare => [ qw(
         weekday
         datetimedate
-        
-        MyDateTime
     ) ];
+        
+        #~ MyDateTime
 use MooseX::Types::Moose qw(
         Object
         HashRef
@@ -21,6 +21,8 @@ use MooseX::Types::Moose qw(
         Int
     );
 
+#########1 Dispatch Tables and Module Variables   5#########6#########7#########8#########9
+
 ### Module variables here
 my  $epochdt = DateTime->new( 
         year => 1970, 
@@ -44,8 +46,9 @@ my  $weekdays = {
         'Saturday'      => 6,
         'Sunday'        => 7,
     };
+my	$local_time_zone = DateTime::TimeZone->new( name => 'local' );
 
-###############  Subtypes  #############################################
+#########1 Subtypes           3#########4#########5#########6#########7#########8#########9
 
 subtype weekday, as Int,
     where{ $_ >= 1 and $_ <= 7 },
@@ -64,11 +67,42 @@ coerce weekday, from Str,
         }
     };
 
-subtype MyDateTime, as Object,
-    where{ $_->isa( 'DateTime' ) },
+subtype datetimedate, as Object,
+	where{ $_->isa( 'DateTime' ) },
     message{ $_ };
 
-coerce MyDateTime, from HashRef,
+coerce datetimedate, from Num|ArrayRef|Str,
+    via {
+        my ( $arg, $type ) = ( ref $_ eq 'ARRAY' ) ? ( @$_ ) : ( $_, undef ) ;#Provides a way to force epoch vs excel
+		$type //=
+			( $arg =~ /^(\d{7,11}|60|0|-\d+)$/  )		? 'epoch'	:#choose epoch style
+			( $arg =~ /^(\d{0,6}(.\d*)?|\d{7,}.\d+)$/ )	? 'excel'	:#choose excel style
+			( $arg =~ /^-\d*.\d+$/ )					? 'bad_num' :#Negative decimals not allowed
+			'string' ;#default to Date::Manip
+		if( $type eq 'bad_num' ){
+			return "Could not use the number -|$arg|- as an Excel date or a Nix date";
+		}
+			
+        my ( $dt, $return );
+		$return =
+			( $type eq 'epoch' ) ?
+				( ( eval{ $dt = $epochformtr->parse_datetime( $arg ) } ) ?
+					$dt : "Attempting to treat -$arg- as a Nix epoch failed in the DateTime conversion" ) :
+			( $type eq 'excel' ) ? 
+				( ( eval{ $dt = DateTime::Format::Excel->parse_datetime( $arg ) } ) ?
+					$dt : "Attempting to treat -$arg- as an Excel serialized date failed in the DateTime conversion\n" ) :
+				undef;
+		if( !$return ){
+			#~ my 	$dm = ParseDate( $arg );
+				$dt = DateTime::Format::Flexible->parse_datetime( $arg, time_zone => $local_time_zone, );
+				#~ $dt->set_time_zone( DateTime::TimeZone->new( name => 'America/Chicago' ) );
+			$return = ( $dt ) ? $dt :
+				"Failed to build a date time from DateTime::Format::DateManip (or any other method) for string -$arg-\n";
+		}
+		return $return;
+    };
+
+coerce datetimedate, from HashRef,
     via{ 
         my $dt;
         my %input = %$_;
@@ -78,46 +112,11 @@ coerce MyDateTime, from HashRef,
         );
     };
 
-subtype datetimedate, as MyDateTime,
-    message{ $_ };
-
-coerce datetimedate, from Num|ArrayRef,
-    via {
-        my ( $arg, $type ) = ( ref $_ eq 'ARRAY' ) ? ( @$_ ) : ( $_, undef ) ;#Provides a way to force epoch vs excel
-        my  $dt;
-        return
-            (   ( $type and $type eq 'epoch' ) or #force epoch 1-Jan-1970 calculation
-                ( $arg =~ /^(\d{7,11}|60|-\d*)$/ ) ) ?#Concedes 1-Jan-1970 to 12-Jan-1970 to excel
-                ( ( eval{ $dt = $epochformtr->parse_datetime( $arg ) } ) ?
-                    $dt : "Attempting to treat -$arg- as a Nix epoch failed in the DateTime conversion" ) :
-                (   ( $type and $type eq 'excel' ) or  #force excel calculation
-                    ( $arg =~ /^\d{0,6}(.\d*)?$/ )      ) ?#Concedes > 27-Nov-4637 to Unix (Excel doesn't recognize dates earlier than Jan 1 1900)
-                    ( ( eval{ $dt = DateTime::Format::Excel->parse_datetime( $arg ) } ) ?
-                        $dt : "Attempting to treat -$arg- as an Excel serialized date failed in the DateTime conversion\n" ) :
-                    "Could not use the number -|$arg|- as an Excel date or a Nix date";
-    };
-
-coerce datetimedate, from Str,
-    via {
-        my $dt;
-        my $input = $_;
-        return(
-            ( eval { $dt = DateTime::Format::DateManip->parse_datetime( $input ) } ) ?
-                $dt : "Failed to build a date time from DateManip with string -$input-\n"
-        );
-    };
-
-###############  Private Type methods  #################################
-
-
-
-#################### Phinish with a Phlourish ##########################
+#########1 Phinish            3#########4#########5#########6#########7#########8#########9
 
 1;
-# The preceding line will help the module return a true value
-
-#################### main pod documentation begin ###################
 
+#########1 main pod docs      3#########4#########5#########6#########7#########8#########9
 __END__
 
 =head1 NAME
@@ -126,7 +125,7 @@ DateTimeX::Mashup::Shiras::Types - Types for DateTimeX::Mashup::Shiras
 
 =head1 SYNOPSIS
     
-    #! C:/Perl/bin/perl
+    #!perl
     package MyPackage;
 
     use Moose;
@@ -146,8 +145,8 @@ Moose found in the western United States (of America).
 
 This is the custom type class that ships with the L<DateTimeX::Mashup::Shiras
 |https://metacpan.org/module/DateTimeX::Mashup::Shiras> package.  Wherever 
-possible errors to coersions are passed back to the type so coersion failure 
-will be explained.
+possible coersion failures are passed back to the type so type errors will be 
+explained.
 
 There are only subtypes in this package!  B<WARNING> These types should be 
 considered in a beta state.  Future type fixing will be done with a set of tests in 
@@ -164,8 +163,8 @@ of this module.
 
 B<Definition: >integers ( 1 .. 7 )
 
-B<Coercions: >from a string.  The type will try to qr//i match the passed string to an 
-english name of the week.
+B<Coercions: >from a string.  The type will try to qr//i match the passed string 
+to an english name of the week.
 
 =back
 
@@ -179,22 +178,24 @@ B<Coercions: >
 
 =over
 
-B<from a number> This will check the number range and attempt to turn any positive number 
-with less than 7 digits left of the decimal into a DateTime object using 
-L<DateTime::Format::Excel|https://metacpan.org/module/DateTime::Format::Excel> 
-it will attempt to turn any integer with more than 6 digits into a DateTime object using 
+B<from a number> This will check the number for 0, 60 (microsoft issues), 
+negative integers, and positive integers with more than 7 digits and read them 
+as epoch (Nixy) dates with the start at January 1st, 1970 using.  
 L<DateTime::Format::Epoch|https://metacpan.org/module/DateTime::Format::Epoch>
-
-B<from an array ref> This will use the second element of the array ref to try and match to 
-either 'epoch' or 'excel'.  If that match works the first element is sent to the 
-number coercion already described but it forces excel or 1-Jan-1970 epoch coersion 
-based on the match.  If the second element is undef or doesn't match then the number 
-test is still performed on the first element.
+It will turn any positive integer or decimial with less than 7 leading digits 
+into an excel date using L<DateTime::Format::Excel
+|https://metacpan.org/module/DateTime::Format::Excel>.  All positive decimals 
+with 7 or more digits will also be treated as excel dates.  Negative decimals 
+will fail.
 
 B<from a string> This will use 
-L<DateTime::Format::DateManip|https://metacpan.org/module/DateTime::Format::DateManip> 
+L<DateTime::Format::Flexible|https://metacpan.org/module/DateTime::Format::Flexible> 
 to try and coerce the string into a DateTime object.
 
+B<from an array ref> This will use the second element of the array ref to try 
+to match 'epoch', 'excel', or 'string'.  If that match works the first element 
+is evaluated as described above otherwise it is evaluated as a string.
+
 =back
 
 =back
@@ -228,6 +229,12 @@ B<2.> Support custom epoch input and changes
 B<3.> Add L<Log::Shiras|https://github.com/jandrew/Log-Shiras> debugging in exchange for
 L<Smart::Comments|https://metacpan.org/module/Smart::Comments>
 
+=over
+
+* Get Log::Shiras CPAN ready first!
+
+=back
+
 =back
 
 =head1 AUTHOR
@@ -248,6 +255,8 @@ it and/or modify it under the same terms as Perl itself.
 The full text of the license can be found in the
 LICENSE file included with this module.
 
+This software is copyrighted (c) 2013 by Jed Lund.
+
 =head1 DEPENDANCIES
 
 =over
@@ -264,7 +273,7 @@ L<DateTime::Format::Epoch|https://metacpan.org/module/DateTime::Format::Epoch>
 
 L<DateTime::Format::Excel|https://metacpan.org/module/DateTime::Format::Excel>
 
-L<DateTime::Format::DateManip|https://metacpan.org/module/DateTime::Format::DateManip>
+L<DateTime::Format::Flexible|https://metacpan.org/module/DateTime::Format::Flexible>
 
 =back
 
@@ -286,4 +295,4 @@ L<DateTimeX::Format|https://metacpan.org/module/DateTimeX::Format>
 
 =cut
 
-#################### main pod documentation end #####################
\ No newline at end of file
+#########1 Main POD ends      3#########4#########5#########6#########7#########8#########9
\ No newline at end of file
